@@ -17,6 +17,7 @@ from .._shared import KLENumberRef
 from .._shared import MOBase
 from .._shared import OrgUnitRef
 from .._shared import Validity
+from ._shared import Details
 
 # --------------------------------------------------------------------------------------
 # KLE models
@@ -56,6 +57,10 @@ class KLEWrite(KLEBase):
     )
 
 
+class KLEDetail(KLEWrite, Details):
+    pass
+
+
 class KLE(KLEBase):
     """Service API-compatible model with singular `kle_aspect`."""
 
